==> klat4-0.5.2.tar.bz2: klat4-0.5.2/klathtmlwidget.cpp <==
/*
    Klat - A LaTeX editor for KDE
    
    Copyright (C) 2002-2004  Jori Liesenborgs (jori@lumumba.luc.ac.be)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "klathtmlwidget.h"
#include "klathtmlwidget.moc"
#include <kurl.h>
#include <kstandarddirs.h>
#include <stdio.h>

#define IMGTOKILEPROT						"imgtokile"
#define IMGTOKLATPROT						"imgtoklat"
#define TXTTOKLATPROT						"txttoklat"

KlatHTMLWidget::KlatHTMLWidget(QWidget *parent) : KHTMLPart(parent)
{
 connect(this,SIGNAL(onURL(const QString &)),this,SLOT(onURLslot(const QString &)));
}

KlatHTMLWidget::~KlatHTMLWidget()
{
}

bool KlatHTMLWidget::urlSelected(const QString &url, int button, int state,const QString &_target, const KParts::OpenUrlArguments& args, const KParts::BrowserArguments& browserArgs)
{
	KHTMLPart::urlSelected(url,button,state,_target,args,browserArgs);
	KUrl cURL = completeURL(url);
	
	if (cURL.protocol() == IMGTOKLATPROT || cURL.protocol() == IMGTOKILEPROT || cURL.protocol() == TXTTOKLATPROT)
	{
//		QString code=(cURL.url().remove(0,11));
		QString code=(QUrl::fromPercentEncoding(url.toLatin1()).remove(0,11));
		int i,len,advance;
		bool found;
		
		len = code.length();
		advance = len;
		if (code.left(6) == QString("\\begin"))
		{
			for (i = 6,found = false ; !found && i < len ; i++)
			{
				if (code[i] == '\\')
				{
					found = true;
					advance = i;
				}
			}	
		}
		else
		{
			for (i = 0,found = false ; !found && i < len ; i++)
			{
				if (code[i] == '{')
				{
					found = true;
					advance = i+1;
				}
			}
		}
		
		emit signalSymbolCodeSelected(code,advance);
	}
}

void KlatHTMLWidget::openAppDataUrl(const QString &relpath)
{
	QString path,urlstr;

	path = KStandardDirs::locate("appdata",relpath);
	urlstr = "file:";
	urlstr += path;
	
	KUrl url(path);
	
	if (url.isValid())
		openUrl(url);
}

void KlatHTMLWidget::onURLslot(const QString& url)
{
  KUrl cURL = completeURL(url);
  if (cURL.protocol() == IMGTOKLATPROT || cURL.protocol() == IMGTOKILEPROT || cURL.protocol() == TXTTOKLATPROT)
  {
//    QString code=(cURL.url().remove(0,11));
    QString code=(QUrl::fromPercentEncoding(url.toLatin1()).remove(0,11));
    emit onURLcode(code);
  } 
}

==> klat4-0.6.1.tar.bz2: klat4-0.6.1/klathtmlwidget.cpp <==
/*
    Klat4 - A LaTeX editor for KDE4
    
    Copyright (C) 2008  Anna A. Ladilova (ladilova@algebraic.ru)
    Copyright (C) 2002-2004  Jori Liesenborgs (jori@lumumba.luc.ac.be)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "klathtmlwidget.h"

#include <KUrl>
#include <KStandardDirs>

#define IMGTOKLATPROT						"imgtoklat"
#define TXTTOKLATPROT						"txttoklat"
#define LTRTOKLATPROT						"ltrtoklat"

KlatHTMLWidget::KlatHTMLWidget(QWidget *parent) : KHTMLPart(parent)
{
	connect(this,SIGNAL(onURL(const QString &)),this,SLOT(onURLslot(const QString &)));
}

KlatHTMLWidget::~KlatHTMLWidget()
{
}

bool KlatHTMLWidget::urlSelected(const QString &url, int button, int state,const QString &_target, const KParts::OpenUrlArguments& args, const KParts::BrowserArguments& browserArgs)
{
	KHTMLPart::urlSelected(url,button,state,_target,args,browserArgs);
	KUrl cURL = completeURL(url);
	
	if (cURL.protocol() == IMGTOKLATPROT || cURL.protocol() == TXTTOKLATPROT || cURL.protocol() == LTRTOKLATPROT)
	{
		QString code=(QUrl::fromPercentEncoding(url.toLatin1()).remove(0,11));
		int i,len,advance;
		bool found;
		
		len = code.length();
		advance = len;
		if (code.left(6) == QString("\\begin"))
		{
			for (i = 6,found = false ; !found && i < len ; i++)
			{
				if (code[i] == '\\')
				{
					found = true;
					advance = i;
				}
			}	
		}
		else
		{
			for (i = 0,found = false ; !found && i < len ; i++)
			{
				if (code[i] == '{')
				{
					found = true;
					advance = i+1;
				}
			}
			if(cURL.protocol() == LTRTOKLATPROT && found == true)
			{
				for (i ,found = false ; !found && i < len ; i++)
				{
					if (code[i] == '}')
					{
						found = true;
						advance = i+1;
					}
				}
			}
		}
		
		emit signalSymbolCodeSelected(code,advance);
	}
}

void KlatHTMLWidget::openAppDataUrl(const QString &relpath)
{
	QString path,urlstr;

	path = KStandardDirs::locate("appdata",relpath);
	urlstr = "file:";
	urlstr += path;
	
	KUrl url(path);
	
	if (url.isValid())
		openUrl(url);
}

void KlatHTMLWidget::onURLslot(const QString& url)
{
  KUrl cURL = completeURL(url);
  if (cURL.protocol() == IMGTOKLATPROT || cURL.protocol() == LTRTOKLATPROT || cURL.protocol() == TXTTOKLATPROT)
  {
    QString code=(QUrl::fromPercentEncoding(url.toLatin1()).remove(0,11));
    emit onURLcode(code);
  } 
}
